
function wenner3lay_fit

% Based on method of Mooney et al (1966)
% Geophysics 31, 192-203

% Coded for 3 layers

close all
clear all


% Indices define layer thicknesses (need to
% integers and code unstable unless idep1=1)
% We overcome this limitation with scaling.

niter = 4000
vmodel=[0.1 1000 10 1200]
vfit  =[0.1 1000 10 300]

% Read data
load telford83.txt
for m =1:10
  adat(m)      = telford83(m,1)/3.28;
  apprhodat(m) = telford83(m,2);
end

% Start loop to re-compute model response / update model
irun =1
while irun ~= -1
   
  %Load model
  load DCmodel3L.txt

  for i=1:3
    z(i)   = DCmodel3L(i,1);
    rho(i) = DCmodel3L(i,2);
  end
  
  scale = z(2)
  idep1=1
  idep2=z(3)/scale

  k1=(rho(2)-rho(1))/(rho(2)+rho(1))
  k2=(rho(3)-rho(2))/(rho(3)+rho(2))
   
% Define p and h coefficients
% offset by 1 since index of 0 is not allowed

  for i=1:niter+2
    p(i)=0.0;
    h(i)=0.0;
    q(i)=0.0;
  end

  h(1) = 1;
  h(idep2-idep1+1) = k1*k2;
  p(idep1+1) = k1;
  p(idep2+1) = k2;

% recurse to compute q coefficients

  q(1) = 0;
  for N =1:niter
    index(N) = N; 
    sum=0.0;
    if N >= idep2
      for isum =1:idep2
        sum=sum+(p(isum+1)-h(isum+1))*q(N+1-isum); 
      end
    else
      for isum=1,N
        sum=sum+(p(1+isum)-h(1+isum))*q(N+1-isum); 
      end
    end

    q(N+1) = p(N+1)+sum;
  end   

  index(N+1)=N+1;
  index(N+2)=N+2;
  length(index);
  length(q);

% Define a=spacing
  iset=0
    for loga =-1.:0.1:2.0
      iset=iset+1;
      a(iset) =10.^(loga);
    end
    
% For given model compute apparent
% resistivity with infinite sum    
    
    for ispace =1:length(a)
      dw=0;
      for m=1 : niter
        f= (m)/a(ispace);
        f2 = f*f;   
        d =q(m)*((2./(sqrt(1.+4*f2)))-(1./(sqrt(1.+f2))));
        icount(m) =m;
        dwm(m)=d;
        dw=dw+d;
        sum(m)=dw;
      end

    rhoapp(ispace) = abs(rho(1)*(1.+2.*dw));

  end
  % end of 'a' loop     
  
% Plot the fit to the measured data
  subplot(2,1,1)
  loglog(scale*a,rhoapp,'b-') 
  hold on  
  loglog(adat,apprhodat,'bo')
% hold off
  axis(vfit)
  xlabel('a(m)')
  ylabel('apparent resistivity (ohm.m)')
  text(30,100,'Fit to measured data')

  rhoplot(1) = rho(1)
  dplot  (1) = 0.001
  rhoplot(2) = rho(1)
  dplot  (2) = z(2)
  rhoplot(3) = rho(2)
  dplot  (3) = z(2)
  rhoplot(4) = rho(2)
  dplot  (4) = z(3)
  rhoplot(5) = rho(3)
  dplot  (5) = z(3)
  rhoplot(6) = rho(3)
  dplot  (6) = 10000.

  
% Plot resistivity model
  subplot(2,1,2)
  loglog (dplot,rhoplot,'b-')
  hold on
  axis(vmodel)
  xlabel('depth(m)')
  ylabel('resistivity (ohm.m)')
  text(30,100,'Resistivity model')
  
   % Change these parameters to get a better fit 
   choice=menu('Options', 'Recompute','Print result and quit')
      
   if choice ==2
    close all
    
    subplot(2,1,1)
    loglog(a*scale,rhoapp,'b-') 
    hold on  
    loglog(adat,apprhodat,'bo')
    hold off
    axis(vfit)
    xlabel('a(m)')
    ylabel('apparent resistivity (ohm.m)')
    text(30,100,'Fit to measured data')

    subplot(2,1,2)
    loglog (dplot,rhoplot,'b-')
    axis(vmodel)
    xlabel('depth(m)')
    ylabel('resistivity (ohm.m)')
    text(30,100,'Resistivity model')
       
    print -dpsc  fit3l.ps
    irun = -1   
 end
 
end